# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`lacework`](#lacework): This class is used to install the Lacework Agent onto a target machine

#### Private Classes

* `lacework::files`: This class is used to control required files for the lacework agent, including config.json
* `lacework::pkg`: This class is used to control package repositories and package installation for the Lacework agent.
* `lacework::service`: This class is used to control the Lacework service.

## Classes

### <a name="lacework"></a>`lacework`

This class will install the Lacework agent onto a target machine.  At a minimum, you must provide the access key to
be used by the agent.

#### Examples

##### 

```puppet
class{'lacework':
  access_token =>  "<your token here>"
}
```

#### Parameters

The following parameters are available in the `lacework` class:

* [`package_ensure`](#package_ensure)
* [`service_ensure`](#service_ensure)
* [`pkg_manage_sources`](#pkg_manage_sources)
* [`access_token`](#access_token)
* [`agent_server_url`](#agent_server_url)
* [`config_tags`](#config_tags)
* [`cmdlinefilter_allow`](#cmdlinefilter_allow)
* [`cmdlinefilter_disallow`](#cmdlinefilter_disallow)
* [`fim_filepath`](#fim_filepath)
* [`fim_fileignore`](#fim_fileignore)
* [`fim_noatime`](#fim_noatime)
* [`fim_runat`](#fim_runat)
* [`fim_mode`](#fim_mode)
* [`container_engine_endpoint`](#container_engine_endpoint)
* [`proxyurl`](#proxyurl)
* [`perfmode`](#perfmode)
* [`cpulimit`](#cpulimit)
* [`memlimit`](#memlimit)
* [`auto_upgrade`](#auto_upgrade)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Used to configure a specific version of the agent to be installed.  Defaults to 'present'.

Default value: `'present'`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `String`

Used to configure the service state.  Defaults to 'running'.

Default value: `'running'`

##### <a name="pkg_manage_sources"></a>`pkg_manage_sources`

Data type: `Boolean`

Control if this module should add package repositories or not.  Defaults to true.

Default value: ``true``

##### <a name="access_token"></a>`access_token`

Data type: `String`

Supply access token for the Lacework agent. See https://support.lacework.com/hc/en-us/articles/360036425594-Create-Agent-Access-Tokens-and-Download-Agent-Installers for info on access tokens.

##### <a name="agent_server_url"></a>`agent_server_url`

Data type: `Enum['https://api.lacework.net',
    'https://api.fra.lacework.net',
  'https://auprodn1.agent.lacework.net']`

Supply the correct server api url. See https://docs.lacework.net/onboarding/agent-server-url for details.

Default value: `'https://api.lacework.net'`

##### <a name="config_tags"></a>`config_tags`

Data type: `Optional[Hash[String, String]]`

Provide agent tags.  See https://support.lacework.com/hc/en-us/articles/360008466893-Add-Agent-Tags for details on agent tags

##### <a name="cmdlinefilter_allow"></a>`cmdlinefilter_allow`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#cmdlinefilter-property for details on 'allow'.

##### <a name="cmdlinefilter_disallow"></a>`cmdlinefilter_disallow`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#cmdlinefilter-property for details on 'allow'.

##### <a name="fim_filepath"></a>`fim_filepath`

Data type: `Optional[Array[String]]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#filepath-property for details on the FIM 'filepath' property.

##### <a name="fim_fileignore"></a>`fim_fileignore`

Data type: `Optional[Array[String]]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#fileignore-property for details on the FIM 'fileignore' property

##### <a name="fim_noatime"></a>`fim_noatime`

Data type: `Optional[Boolean]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#noatime-property for details on the FIM 'noatime' property

##### <a name="fim_runat"></a>`fim_runat`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#runat-property for details on the FIM 'runat' property

##### <a name="fim_mode"></a>`fim_mode`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#mode-property for details on the FIM 'mode' property

##### <a name="container_engine_endpoint"></a>`container_engine_endpoint`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#containerengineendpoint-property for details on the 'container_engine_endpoint' parameter.

##### <a name="proxyurl"></a>`proxyurl`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#proxyurl-property for details on using a proxy in the agent.

##### <a name="perfmode"></a>`perfmode`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#perfmode-property for details on the perfmode parameter.

##### <a name="cpulimit"></a>`cpulimit`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#cpulimit-property for details on setting agent CPU limits.

##### <a name="memlimit"></a>`memlimit`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#memlimit-property for details on setting agent memory limits.

##### <a name="auto_upgrade"></a>`auto_upgrade`

Data type: `Optional[String]`

See https://support.lacework.com/hc/en-us/articles/360024365753-Configure-Agent-Behavior-in-config-json-File#autoupgrade-property for details on configuring agent auto-upgrades.

